Mailbox

Struct Mailbox 

pub struct Mailbox { /* private fields */ }
Classic 8x8 square board representation of Chess board. Mailbox is Square-Centric, meaning it indexes by square to get a piece, as opposed to a PieceSets which indexes by piece to get squares. Index starts at A1. A1 = idx 0 B1 = idx 1 A2 = idx 8 H7 = idx 63

Implementations

Source

impl Mailbox

pub const FILES: usize = NUM_FILES

pub const RANKS: usize = NUM_RANKS

pub const SIZE: usize = NUM_SQUARES

pub fn new() -> Self

Creates an empty Mailbox, where all squares are None.

pub fn start_position() -> Self

Create Mailbox with pieces arranged in starting chess position.

pub fn board(&self) -> &[Option<Piece>; 64]

pub fn pretty(&self) -> String

Returns pretty-printed chess board representation of Self. The chess board has borders and file/rank indicators.