PieceSets

Struct PieceSets 

pub struct PieceSets { /* private fields */ }
A Piece-Centric representation of pieces on a chessboard. A Bitboard is used to encode the squares of each chess piece. PieceSets indexes by piece to get squares, as opposed to Mailbox which indexes by square to get a piece.

Implementations

Source

impl PieceSets

pub fn new() -> Self

Returns PieceSets with all Bitboards set to empty.

pub fn start_position() -> Self

Returns PieceSets arranged in starting chess position.

pub fn occupied(&self) -> Bitboard

Return a bitboard representing the set of squares occupied by any piece. Note: Compiler can auto-vectorize, however looking at assembly on godbolt may be limited to avx128. Does not seem to use avx512 on supported cpus.

pub fn color_occupied(&self, color: Color) -> Bitboard

Return a bitboard representing the set of squares occupied by piece of color.

pub fn on_square(&self, sq: Square) -> Option<Piece>

Finds and returns the first piece found on target square, or None.

pub fn on_player_square(&self, player: Color, sq: Square) -> Option<PieceKind>

Finds and returns the first PieceKind found on target square of player’s pieces, or None.

pub fn pretty(&self) -> String

Returns pretty-printed chess board representation of Self. Uses Mailbox pretty.

pub fn is_disjoint(&self) -> bool

Returns true if all sets in self are disjoint (mutually exclusive). In other words, there is no more than 1 piece per square. If a square is in one set, it is in no other. PieceSets should be disjoint at all times.

pub fn is_valid(&self) -> bool

Returns true if Self is valid. A valid PieceSets has the following properties:

  • Has a single king per side.
  • Each bitboard is disjoint (mutually exclusive) meaning a square cannot have more than one piece.