EngineBuilder

Struct EngineBuilder 

pub struct EngineBuilder { /* private fields */ }
EngineBuilder allows for parameters of an Engine to be set and built once, avoiding repeating costly initialization steps of making then changing an Engine.

Default values:

  • game: Starting chess position
  • transpositions_mb: 1 megabytes
  • num_threads: 1,
  • debug: true

Implementations

Source

impl EngineBuilder

pub fn new() -> Self

Create a new default EngineBuilder.

pub fn build(&self) -> Engine

Create and return a new Engine.

pub fn game(self, game: Game) -> Self

Set the Engine’s initial game state.

pub fn position(self, position: Position) -> Self

Set the Engine’s initial game state from a position with no history.

pub fn threads(self, num_threads: usize) -> Self

Set the engine’s initial search thread pool size.

pub fn transpositions_mb(self, transpositions_mb: usize) -> Self

Set the engine’s initial transposition table size in megabytes.

pub fn debug(self, debug: bool) -> Self

Set whether the engine begins in debug mode.