Fen

Trait Fen 

pub trait Fen: Sized {
    // Required methods
    fn parse_fen(s: &str) -> Result<Self, ParseFenError>;
    fn to_fen(&self) -> String;

    // Provided methods
    fn parse_halfmove_clock(s: &str) -> Result<MoveCount, ParseFenError> { ... }
    fn parse_fullmove_number(s: &str) -> Result<MoveCount, ParseFenError> { ... }
}
Implement Fen for any types which can be fully parsed from a FEN string.

Required Methods

fn parse_fen(s: &str) -> Result<Self, ParseFenError>

Attempt to parse a Fen string into implementing type.

fn to_fen(&self) -> String

Returns string representation of implementing type in Fen format.

Provided Methods

fn parse_halfmove_clock(s: &str) -> Result<MoveCount, ParseFenError>

HalfMove Clock is any non-negative number.

fn parse_fullmove_number(s: &str) -> Result<MoveCount, ParseFenError>

FullMove Number starts at 1, and can increment infinitely.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors