pub struct ThreadPool { /* private fields */ }Expand description
Long-lived thread pool containing n threads for job processing.
Requirements: ThreadPool needs to know which threads are available at any given time. A ThreadPool is expected to live for the duration of the engine. Must be sharable b/t threads. The ThreadPool manages all threads within it, the threads may not outlive it.
Implementations