pub fn minimax(position: Position, ply: PlyKind) -> SearchResultExpand description
Base minimax call. This function assumes that the current player in the passed position is the engine. It returns the best move and score for the position in the search tree.