pub fn negamax(
position: Position,
ply: PlyKind,
tt: &TranspositionTable,
) -> SearchResultExpand description
Negamax implementation of Minimax with alpha-beta pruning. Negamax searches to a given depth and returns the best move found. Internally, Negamax treats the active player as the maxing player, however the final centipawn score of the position returned is absolute with White as maxing and Black as minning.