pub fn search_nonblocking<P, T>(
game: P,
mode: Mode,
tt: Arc<TranspositionTable>,
stopper: Arc<AtomicBool>,
debug: bool,
sender: Sender<T>,
) -> JoinHandle<()>Expand description
Blunders Engine non-blocking search function. This runs the search on a separate thread. When the search has been completed, it returns the value by sending it over the given Sender.
Arguments
game: State of the current active gamemode: Mode of search determines when the search stops and how deep it searchestt: Shared Transposition table. This may or may not lock the table for the duration of the searchstopper: Tell search to stop early from an external sourcedebug: When true prints extra debugging informationsender: Channel to send search result over